@@ -8,18 +8,16 @@ Time::Format - Easy-to-use date/time formatting.
 
 =head1 VERSION
 
-This documentation describes version 0.11 of Time::Format.pm, July 11, 2003.
+This documentation describes version 0.12 of Time::Format.pm, July 17, 2003.
 
 =cut
 
 use strict;
 package Time::Format;
 
-$Time::Format::VERSION = '0.11';
-my @EXPORT      = qw(%time time_format);
-my @EXPORT_OK   = qw(%time %strftime %manip time_format time_strftime time_manip);
+$Time::Format::VERSION = '0.12';
 
-# Check whether optional XS module is installed
+# Check whether the optional XS module is installed.
 eval { require Time::Format_XS };
 if (!$@  &&  defined &Time::Format_XS::time_format)
 {
@@ -30,12 +28,18 @@ if (!$@  &&  defined &Time::Format_XS::time_format)
         Time::Format_XS::time_format($fmt, $time);
     }
 }
+else    # Time::Format_XS not installed.  Load the perl routines to do it.
+{
+    local $/ = undef;
+    eval <DATA>;
+    die if $@;
+}
 
-use vars qw(%time %strftime %manip);
-tie %time,     'Time::Format', \&time_format;
-tie %strftime, 'Time::Format', \&time_strftime;
-tie %manip,    'Time::Format', \&time_manip;
+my @EXPORT      = qw(%time time_format);
+my @EXPORT_OK   = qw(%time %strftime %manip time_format time_strftime time_manip);
 
+# We don't need any of Exporter's fancy features, so it's quicker to
+# do the import ourselves.
 sub import
 {
     my $pkg  = shift;
@@ -84,6 +88,20 @@ sub import
     }
 }
 
+# Simple tied-hash implementation.
+
+# Each hash is simply tied to a subroutine reference.  "Fetching" a
+# value from the hash invokes the subroutine.  If a hash (tied or
+# otherwise) has multiple comma-separated values but the leading
+# character is a $, then Perl joins the values with $;.  This makes it
+# easy to simulate function calls with tied hashes -- we just split on
+# $; to recreate the argument list.
+
+use vars qw(%time %strftime %manip);
+tie %time,     'Time::Format', \&time_format;
+tie %strftime, 'Time::Format', \&time_strftime;
+tie %manip,    'Time::Format', \&time_manip;
+
 sub TIEHASH
 {
     my $class = shift;
@@ -107,6 +125,7 @@ use subs qw(
     die "Invalid call to Time::Format internal function at $file line $line.";
 };
 
+
 # Module finder
 {
     my %have;
@@ -125,199 +144,6 @@ use subs qw(
 }
 
 
-# Default names for months, days
-my %english_names =
-(
- Month    => [qw[January February March April May June July August September October November December]],
- Weekday  => [qw[Sunday Monday Tuesday Wednesday Thursday Friday Saturday]],
- th       => [qw[/th st nd rd th th th th th th th th th th th th th th th th th st nd rd th th th th th th th st]],
-);
-my %names;
-my $locale;
-my %loc_cache;              # Cache for remembering times that have already been parsed out.
-my $cache_size=0;           # Number of keys in %loc_cache
-my $cache_size_limit = 256; # Max number of times to cache
-
-# Internal function to initialize locale info
-sub setup_locale
-{
-    # Do nothing if locale has not changed since %names was set up.
-    my $locale_in_use;
-    $locale_in_use = POSIX::setlocale(POSIX::LC_TIME()) if _have('POSIX');
-    $locale_in_use = '' if  !defined $locale_in_use;
-    return if defined $locale  &&  $locale eq $locale_in_use;
-
-    my (@Month, @Mon, @Weekday, @Day);
-
-    eval {
-        require I18N::Langinfo;
-        I18N::Langinfo->import
-                qw(  MON_1   MON_2   MON_3   MON_4   MON_5   MON_6   MON_7   MON_8   MON_9   MON_10   MON_11   MON_12
-                     ABMON_1 ABMON_2 ABMON_3 ABMON_4 ABMON_5 ABMON_6 ABMON_7 ABMON_8 ABMON_9 ABMON_10 ABMON_11 ABMON_12
-                     DAY_1   DAY_2   DAY_3   DAY_4   DAY_5   DAY_6   DAY_7
-                     ABDAY_1 ABDAY_2 ABDAY_3 ABDAY_4 ABDAY_5 ABDAY_6 ABDAY_7
-                     langinfo);
-        @Month = map langinfo($_),   MON_1(),   MON_2(),   MON_3(),   MON_4(),    MON_5(),    MON_6(),
-                                     MON_7(),   MON_8(),   MON_9(),   MON_10(),   MON_11(),   MON_12();
-        @Mon   = map langinfo($_), ABMON_1(), ABMON_2(), ABMON_3(), ABMON_4(),  ABMON_5(),  ABMON_6(),
-                                   ABMON_7(), ABMON_8(), ABMON_9(), ABMON_10(), ABMON_11(), ABMON_12();
-        @Weekday = map langinfo($_),   DAY_1(),   DAY_2(),   DAY_3(),   DAY_4(),   DAY_5(),   DAY_6(),   DAY_7();
-        @Day     = map langinfo($_), ABDAY_1(), ABDAY_2(), ABDAY_3(), ABDAY_4(), ABDAY_5(), ABDAY_6(),  ABDAY_7();
-    };
-    if ($@)    # Internationalization didn't work for some reason; go with English.
-    {
-        @Month   = @{ $english_names{Month} };
-        @Weekday = @{ $english_names{Weekday} };
-        @Mon     = map substr($_,0,3), @Month;
-        @Day     = map substr($_,0,3), @Weekday;
-    }
-
-    # Store in %names, setting proper case
-    $names{Month}   = [map ucfirst lc, @Month];
-    $names{Weekday} = [map ucfirst lc, @Weekday];
-    $names{Mon}     = [map ucfirst lc, @Mon];
-    $names{Day}     = [map ucfirst lc, @Day];
-    $names{th}      = $english_names{th};
-    $names{TH}      = [map uc, @{$english_names{th}}];
-
-    foreach my $name (keys %names)
-    {
-        my $aref = $names{$name};
-        @$aref = map ucfirst lc, @$aref;       # mixed-case
-        $names{uc $name} = [map uc, @$aref];   # upper=case
-        $names{lc $name} = [map lc, @$aref];   # lower-case
-    }
-
-    %loc_cache = ();          # locale changes are rare.  Clear out cache.
-    $cache_size = 0;
-    $locale = $locale_in_use;
-}
-
-
-# Helper function -- returns localtime() hashref
-sub _loctime
-{
-    my $time;
-    if (@_  &&  $_[0] ne 'time')
-    {
-        $time = shift;
-    }
-    else
-    {
-        $time = _have('Time::HiRes')? Time::HiRes::time() : time();
-    }
-    my $it = int $time;
-    my $msec = sprintf '%03d', int (    1_000 * ($time - $it));
-    my $usec = sprintf '%06d', int (1_000_000 * ($time - $it));
-
-    setup_locale;
-
-    # Cached, because I expect this'll be called on the same time values frequently.
-    if (exists $loc_cache{$it})
-    {
-        my $h = $loc_cache{$it};
-        @$h{qw/mmm uuuuuu/} = ($msec, $usec);
-        return $h;
-    }
-
-    my @t = localtime int $time;
-    my ($h,$d,$mx,$wx) = @t[2,3,4,6];    # Month, hour, Month, Weekday indexes.
-    $t[4]++;
-    my $h12 = $h>12? $h-12 : ($h || 12);
-    my $tz = _have('POSIX')? POSIX::strftime('%Z',@t) : '';
-
-    # Populate a whole mess o' data elements
-    my %th;
-
-    # NOTE: When adding new codes, be wary of adding any that interfere
-    # with the user's ability to use the words "at", "on", or "of" literally.
-
-    # year, hour(12), month, day, hour, minute, second, millisecond, microsecond, time zone
-    @th{qw[yyyy H  m{on}  d  h  m{in}  s  mmm uuuuuu tz]} = (    $t[5]+1900, $h12, @t[4,3,2,1,0], $msec, $usec, $tz);
-    @th{qw[yy  HH mm{on} dd hh mm{in} ss]} = map $_<10?"0$_":$_, $t[5]%100,  $h12, @t[4,3,2,1,0];
-    @th{qw[    ?H ?m{on} ?d ?h ?m{in} ?s]} = map $_<10?" $_":$_,             $h12, @t[4,3,2,1,0];
-
-    # AM/PM
-    my $a = $h<12? 'a' : 'p';
-    $th{am}     = $th{pm}     = $a . 'm';
-    $th{'a.m.'} = $th{'p.m.'} = $a . '.m.';
-    @th{qw/AM PM A.M. P.M./} = map uc, @th{qw/am pm a.m. p.m./};
-
-    $th{$_} = $names{$_}[$wx] for qw/Weekday WEEKDAY weekday Day DAY day/;
-    $th{$_} = $names{$_}[$mx] for qw/Month   MONTH   month   Mon MON mon/;
-    $th{$_} = $names{$_}[$d]  for qw/th TH/;
-
-    # Don't let the time cache grow boundlessly.
-    if (++$cache_size == $cache_size_limit)
-    {
-        $cache_size = 0;
-        %loc_cache = ();
-    }
-    return $loc_cache{$it} = \%th;
-}
-
-
-my %disam;    # Disambiguator for 'm' format.
-$disam{$_} = "{on}" foreach qw/yy d dd ?d/;           # If year or day is nearby, it's 'month'
-$disam{$_} = "{in}" foreach qw/h hh ?h H HH ?H s ss ?s/;   # If hour or second is nearby, it's 'minute'
-sub time_format
-{
-    my $fmt  = shift;
-    my $time = &_loctime;
-
-    # "Guess" how to interpret ambiguous 'm'
-    $fmt =~ s/
-              (?<!\\)          # Must not follow a backslash
-              (?=[ydhH])       # Must start with one of these
-              (                # $1 begins
-                (              # $2 begins.  Capture:
-                    yy         #     a year
-                  | [dhH]      #     a day or hour
-                )
-              [^?m\\]?         # Followed by something that's not part of a month
-              )
-              (?![?m]?m\{[io]n\})   # make sure it's not already unambiguous
-              (?!mon)          # don't confuse "mon" with "m" "on"
-              ([?m]?m)         # $3 is a month code
-             /$1$3$disam{$2}/gx;
-
-    $fmt =~ s/(?<!\\)         # ignore things that begin with backslash
-              ([?m]?m)        # $1 is a month code
-              (               # $2 begins.
-                 [^\\]?       #     0 or 1 characters
-                 (?=[?dsy])   #     Next char must be one of these
-                 (            #     $3 begins.  Capture:
-                    \??[ds]   #         a day or a second
-                  | yy        #         or a year
-                 )
-              )/$1$disam{$3}$2/gx;
-
-    # The Big Date/Time Pattern
-    $fmt =~ s/
-              (?<!\\)                      # Don't expand something preceded by backslash
-              (?=[dDy?hHsaApPMmWwutT])     # Jump to one of these characters
-              (
-                 [Dd]ay|DAY                # Weekday abbreviation
-              |  yy(?:yy)?                 # Year
-              |  [?m]?m\{[oi]n\}           # Unambiguous month-minute codes
-              |  th | TH                   # day suffix
-              |  [?d]?d                    # Day
-              |  [?h]?h                    # Hour (24)
-              |  [?H]?H                    # Hour (12)
-              |  [?s]?s                    # Second
-              |  [apAP]\.?[mM]\.?          # am and pm strings
-              |  [Mm]on(?:th)?|MON(?:TH)?  # Month names and abbrev
-              |  [Ww]eekday|WEEKDAY        # Weekday names
-              |  mmm|uuuuuu                # millisecond and microsecond
-              |  tz                        # time zone
-             )/$time->{$1}/gx;
-
-    $fmt =~ tr/\\//d;
-    return $fmt;
-}
-
-
-
 # POSIX strftime, for people who like those weird % formats.
 sub time_strftime
 {
@@ -356,28 +182,297 @@ sub time_manip
 }
 
 1;
+__DATA__
+#line __LINE__ __FILE__
+# The following is only compiled if Time::Format_XS is not available.
+
+
+# Default names for months, days
+my %english_names =
+(
+ Month    => [qw[January February March April May June July August September October November December]],
+ Weekday  => [qw[Sunday Monday Tuesday Wednesday Thursday Friday Saturday]],
+ th       => [qw[/th st nd rd th th th th th th th th th th th th th th th th th st nd rd th th th th th th th st]],
+);
+my %names;
+my $locale;
+my %loc_cache;              # Cache for remembering times that have already been parsed out.
+my $cache_size=0;           # Number of keys in %loc_cache
+my $cache_size_limit = 256; # Max number of times to cache
+
+# Internal function to initialize locale info.
+sub setup_locale
+{
+    # Do nothing if locale has not changed since %names was set up.
+    my $locale_in_use;
+    $locale_in_use = POSIX::setlocale(POSIX::LC_TIME()) if _have('POSIX');
+    $locale_in_use = '' if  !defined $locale_in_use;
+    return if defined $locale  &&  $locale eq $locale_in_use;
+
+    my (@Month, @Mon, @Weekday, @Day);
+
+    eval {
+        require I18N::Langinfo;
+        I18N::Langinfo->import qw(langinfo);
+        @Month = map langinfo($_),   I18N::Langinfo::MON_1(),    I18N::Langinfo::MON_2(),    I18N::Langinfo::MON_3(),
+                                     I18N::Langinfo::MON_4(),    I18N::Langinfo::MON_5(),    I18N::Langinfo::MON_6(),
+                                     I18N::Langinfo::MON_7(),    I18N::Langinfo::MON_8(),    I18N::Langinfo::MON_9(),
+                                     I18N::Langinfo::MON_10(),   I18N::Langinfo::MON_11(),   I18N::Langinfo::MON_12();
+        @Mon   = map langinfo($_),   I18N::Langinfo::ABMON_1(),  I18N::Langinfo::ABMON_2(),  I18N::Langinfo::ABMON_3(),
+                                     I18N::Langinfo::ABMON_4(),  I18N::Langinfo::ABMON_5(),  I18N::Langinfo::ABMON_6(),
+                                     I18N::Langinfo::ABMON_7(),  I18N::Langinfo::ABMON_8(),  I18N::Langinfo::ABMON_9(),
+                                     I18N::Langinfo::ABMON_10(), I18N::Langinfo::ABMON_11(), I18N::Langinfo::ABMON_12();
+        @Weekday = map langinfo($_), I18N::Langinfo::DAY_1(),    I18N::Langinfo::DAY_2(),    I18N::Langinfo::DAY_3(),
+            I18N::Langinfo::DAY_4(), I18N::Langinfo::DAY_5(),    I18N::Langinfo::DAY_6(),    I18N::Langinfo::DAY_7();
+        @Day     = map langinfo($_), I18N::Langinfo::ABDAY_1(),  I18N::Langinfo::ABDAY_2(),  I18N::Langinfo::ABDAY_3(),
+          I18N::Langinfo::ABDAY_4(), I18N::Langinfo::ABDAY_5(),  I18N::Langinfo::ABDAY_6(),  I18N::Langinfo::ABDAY_7();
+    };
+    if ($@)    # Internationalization didn't work for some reason; go with English.
+    {
+        @Month   = @{ $english_names{Month} };
+        @Weekday = @{ $english_names{Weekday} };
+        @Mon     = map substr($_,0,3), @Month;
+        @Day     = map substr($_,0,3), @Weekday;
+    }
+
+    # Store in %names, setting proper case
+    $names{Month}   = \@Month;
+    $names{Weekday} = \@Weekday;
+    $names{Mon}     = \@Mon;
+    $names{Day}     = \@Day;
+    $names{th}      = $english_names{th};
+    $names{TH}      = [map uc, @{$names{th}}];
+
+    foreach my $name (keys %names)
+    {
+        my $aref = $names{$name};              # locale-native case
+        $names{uc $name} = [map uc, @$aref];   # upper=case
+        $names{lc $name} = [map lc, @$aref];   # lower-case
+    }
+
+    %loc_cache = ();          # locale changes are rare.  Clear out cache.
+    $cache_size = 0;
+    $locale = $locale_in_use;
+}
+
+
+# Helper function -- returns localtime() hashref
+sub _loctime
+{
+    my $time;
+    if (@_  &&  $_[0] ne 'time')
+    {
+        $time = shift;
+    }
+    else
+    {
+        $time = _have('Time::HiRes')? Time::HiRes::time() : time();
+    }
+    my $it = int $time;
+    my $msec = sprintf '%03d', int (    1_000 * ($time - $it));
+    my $usec = sprintf '%06d', int (1_000_000 * ($time - $it));
+
+    setup_locale;
+
+    # Cached, because I expect this'll be called on the same time values frequently.
+    if (exists $loc_cache{$it})
+    {
+        my $h = $loc_cache{$it};
+        @$h{qw/mmm uuuuuu/} = ($msec, $usec);
+        return $h;
+    }
+
+    my @t = localtime $it;
+    my ($h,$d,$mx,$wx) = @t[2,3,4,6];    # Month, hour, Month, Weekday indexes.
+    $t[4]++;
+    my $h12 = $h>12? $h-12 : ($h || 12);
+    my $tz = _have('POSIX')? POSIX::strftime('%Z',@t) : '';
+
+    # Populate a whole mess o' data elements
+    my %th;
+
+    # NOTE: When adding new codes, be wary of adding any that interfere
+    # with the user's ability to use the words "at", "on", or "of" literally.
+
+    # year, hour(12), month, day, hour, minute, second, millisecond, microsecond, time zone
+    @th{qw[yyyy H  m{on}  d  h  m{in}  s  mmm uuuuuu tz]} = (    $t[5]+1900, $h12, @t[4,3,2,1,0], $msec, $usec, $tz);
+    @th{qw[yy  HH mm{on} dd hh mm{in} ss]} = map $_<10?"0$_":$_, $t[5]%100,  $h12, @t[4,3,2,1,0];
+    @th{qw[    ?H ?m{on} ?d ?h ?m{in} ?s]} = map $_<10?" $_":$_,             $h12, @t[4,3,2,1,0];
+
+    # AM/PM
+    my $a = $h<12? 'a' : 'p';
+    $th{am}     = $th{pm}     = $a . 'm';
+    $th{'a.m.'} = $th{'p.m.'} = $a . '.m.';
+    @th{qw/AM PM A.M. P.M./} = map uc, @th{qw/am pm a.m. p.m./};
+
+    $th{$_} = $names{$_}[$wx] for qw/Weekday WEEKDAY weekday Day DAY day/;
+    $th{$_} = $names{$_}[$mx] for qw/Month   MONTH   month   Mon MON mon/;
+    $th{$_} = $names{$_}[$d]  for qw/th TH/;
+
+    # Don't let the time cache grow boundlessly.
+    if (++$cache_size == $cache_size_limit)
+    {
+        $cache_size = 0;
+        %loc_cache = ();
+    }
+    return $loc_cache{$it} = \%th;
+}
+
+# The heart of the module.  Didja ever see so many wicked regexes in a row?
+
+my %disam;    # Disambiguator for 'm' format.
+$disam{$_} = "{on}" foreach qw/yy d dd ?d/;           # If year or day is nearby, it's 'month'
+$disam{$_} = "{in}" foreach qw/h hh ?h H HH ?H s ss ?s/;   # If hour or second is nearby, it's 'minute'
+sub time_format
+{
+    my $fmt  = shift;
+    my $time = &_loctime;
+
+    # Remove \Q...\E sequences
+    my $rc;
+    if (index($fmt, '\Q') >= 0)
+    {
+        $rc = init_store($fmt);
+        $fmt =~ s/\\Q(.*?)(?:\\E|$)/remember($1)/seg;
+    }
+
+    # "Guess" how to interpret ambiguous 'm'
+    $fmt =~ s/
+              (?<!\\)          # Must not follow a backslash
+              (?=[ydhH])       # Must start with one of these
+              (                # $1 begins
+                (              # $2 begins.  Capture:
+                    yy         #     a year
+                  | [dhH]      #     a day or hour
+                )
+              [^?m\\]?         # Followed by something that's not part of a month
+              )
+              (?![?m]?m\{[io]n\})   # make sure it's not already unambiguous
+              (?!mon)          # don't confuse "mon" with "m" "on"
+              ([?m]?m)         # $3 is a month code
+             /$1$3$disam{$2}/gx;
+
+    # Ambiguous 'm', part 2.
+    $fmt =~ s/(?<!\\)         # ignore things that begin with backslash
+              ([?m]?m)        # $1 is a month code
+              (               # $2 begins.
+                 [^\\]?       #     0 or 1 characters
+                 (?=[?dsy])   #     Next char must be one of these
+                 (            #     $3 begins.  Capture:
+                    \??[ds]   #         a day or a second
+                  | yy        #         or a year
+                 )
+              )/$1$disam{$3}$2/gx;
+
+    # The Big Date/Time Pattern
+    $fmt =~ s/
+              (?<!\\)                      # Don't expand something preceded by backslash
+              (?=[dDy?hHsaApPMmWwutT])     # Jump to one of these characters
+              (
+                 [Dd]ay|DAY                # Weekday abbreviation
+              |  yy(?:yy)?                 # Year
+              |  [?m]?m\{[oi]n\}           # Unambiguous month-minute codes
+              |  th | TH                   # day suffix
+              |  [?d]?d                    # Day
+              |  [?h]?h                    # Hour (24)
+              |  [?H]?H                    # Hour (12)
+              |  [?s]?s                    # Second
+              |  [apAP]\.?[mM]\.?          # am and pm strings
+              |  [Mm]on(?:th)?|MON(?:TH)?  # Month names and abbrev
+              |  [Ww]eekday|WEEKDAY        # Weekday names
+              |  mmm|uuuuuu                # millisecond and microsecond
+              |  tz                        # time zone
+             )/$time->{$1}/gx;
+
+    # Simulate \U \L \u \l
+    $fmt =~ s/((?:\\[UL])+)((?:\\[ul])+)/$2$1/g;
+    $fmt =~ s/\\U(.*?)(?=\\[EULul]|$)/\U$1/gs;
+    $fmt =~ s/\\L(.*?)(?=\\[EULul]|$)/\L$1/gs;
+    $fmt =~ s/\\l(.)/\l$1/gs;
+    $fmt =~ s/\\u(.)/\u$1/gs;
+    $fmt =~ s/\\E//g;
+
+    $fmt =~ tr/\\//d;    # Remove extraneous backslashes.
+
+    if (defined $rc)    # Fixup \Q \E regions.
+    {
+        $fmt =~ s/$rc(..)/recall($1)/seg;
+    }
+    return $fmt;
+}
+
+# Code for remembering/restoring \Q...\E regions.
+# init_store finds a sigil character that's not used within the format string.
+# remember stores a string in the next slot in @store, and returns a coded replacement.
+# recall looks up and returns a string from @store.
+{
+    my $rcode;
+    my @store;
+    my $stx;
+
+    sub init_store
+    {
+        my $str = shift;
+        $stx = 0;
+        return $rcode = "\x01" unless index($str,"\x01") >= 0;
+
+        for ($rcode="\x02"; $rcode<"\xFF"; $rcode=chr(1+ord $rcode))
+        {
+            return $rcode unless index($str, $rcode) >= 0;
+        }
+        die "Time::Format cannot process string: no unique characters left.";
+    }
+
+    sub remember
+    {
+        my $enc;
+        do    # Must not return a code that contains a backslash
+        {
+            $enc = pack 'S', $stx++;
+        } while index($enc, '\\') >= 0;
+
+        $store[$stx-1] = shift;
+        return join '', map "\\$_", split //, "$rcode$enc";    # backslash-escape it!
+    }
+
+    sub recall
+    {
+        return $store[unpack 'S', shift];
+    }
+}
+
 __END__
 
 =head1 SYNOPSIS
 
  use Time::Format qw(%time %strftime %manip);
 
+ $time{$format}
+ $time{$format, $unixtime}
+ 
  print "Today is $time{'yyyy/mm/dd'}\n";
  print "Yesterday was $time{'yyyy/mm/dd', time-24*60*60}\n";
  print "The time is $time{'hh:mm:ss'}\n";
  print "Another time is $time{'H:mm am tz', $another_time}\n";
  print "Timestamp: $time{'yyyymmdd.hhmmss.mmm'}\n";
 
+ $strftime{$format}
+ $strftime{$format, $unixtime}
+ $strftime{$format, $sec,$min,$hour, $mday,$mon,$year, $wday,$yday,$isdst}
+ 
  print "POSIXish: $strftime{'%A, %B %d, %Y', 0,0,0,12,11,95,2}\n";
  print "POSIXish: $strftime{'%A, %B %d, %Y', 1054866251}\n";
  print "POSIXish: $strftime{'%A, %B %d, %Y'}\n";       # current time
 
+ $manip{$format};
+ $manip{$format,$when};
+ 
  print "Date::Manip: $manip{'%m/%d/%Y'}\n";            # current time
  print "Date::Manip: $manip{'%m/%d/%Y','last Tuesday'}\n";
 
  # These can also be used as standalone functions:
  use Time::Format qw(time_format time_strftime time_manip);
-
+ 
  print "Today is ", time_format('yyyy/mm/dd', $some_time), "\n";
  print "POSIXish: ", time_strftime('%A %B %d, %Y',$some_time), "\n";
  print "Date::Manip: ", time_manip('%m/%d/%Y',$some_time), "\n";
@@ -385,29 +480,31 @@ __END__
 =head1 DESCRIPTION
 
 This module creates global pseudovariables which format dates and
-times.  The nice thing about having a variable-like interface instead
-of function calls is that the values can be used inside of strings (as
-well as outside of strings in ordinary expressions).  Dates are
-frequently used within strings (log messages, output, data records,
-etc), so having the ability to interpolate them directly is handy.
-
-Perl allows arbitrary expressions within curly braces of a hash, even
-when that hash is being interpolated into a string.  This allows you
-to do computations on the fly while formatting times and inserting
-them into strings.  See the "yesterday" example above.
+times, according to formatting codes you pass to it in strings.
 
 The C<%time> formatting codes are designed to be easy to remember and
 use, and to take up just as many characters as the output time value
 whenever possible.  For example, the four-digit year code is
 "C<yyyy>", the three-letter month abbreviation is "C<Mon>".
 
+The nice thing about having a variable-like interface instead
+of function calls is that the values can be used inside of strings (as
+well as outside of strings in ordinary expressions).  Dates are
+frequently used within strings (log messages, output, data records,
+etc.), so having the ability to interpolate them directly is handy.
+
+Perl allows arbitrary expressions within curly braces of a hash, even
+when that hash is being interpolated into a string.  This allows you
+to do computations on the fly while formatting times and inserting
+them into strings.  See the "yesterday" example above.
+
 The format strings are designed with programmers in mind.  What do you
 need most frequently?  4-digit year, month, day, 24-based hour,
 minute, second -- usually with leading zeroes.  These six are the
 easiest formats to use and remember in Time::Format: C<yyyy>, C<mm>,
 C<dd>, C<hh>, C<mm>, C<ss>.  Variants on these formats follow a simple
 and consistent formula.  This module is for everyone who is weary of
-trying to remember L<strftime(3)>'s arcane codes, or of endlessly
+trying to remember I<strftime(3)>'s arcane codes, or of endlessly
 writing C<$t[4]++; $t[5]+=1900>.
 
 Note that C<mm> (and related codes) are used both for months and
@@ -445,8 +542,8 @@ is used.  The format string may contain any of the following:
     yyyy       4-digit year
     yy         2-digit year
     
-    mm         2-digit month, 01-12
     m          1- or 2-digit month, 1-12
+    mm         2-digit month, 01-12
     ?m         month with leading space if < 10
     
     Month      full month name, mixed-case
@@ -455,8 +552,8 @@ is used.  The format string may contain any of the following:
     Mon        3-letter month abbreviation, mixed-case
     MON  mon   ditto, uppercase and lowercase versions
     
-    dd         day number, 01-31
     d          day number, 1-31
+    dd         day number, 01-31
     ?d         day with leading space if < 10
     th         day suffix (st, nd, rd, or th)
     TH         uppercase suffix
@@ -467,21 +564,21 @@ is used.  The format string may contain any of the following:
     Day        3-letter weekday name, mixed-case
     DAY  day   ditto, uppercase and lowercase versions
     
-    hh         hour, 00-23
     h          hour, 0-23
+    hh         hour, 00-23
     ?h         hour, 0-23 with leading space if < 10
     
-    HH         hour, 01-12
     H          hour, 1-12
+    HH         hour, 01-12
     ?H         hour, 1-12 with leading space if < 10
     
-    mm         minute, 00-59
     m          minute, 0-59
+    mm         minute, 00-59
     ?m         minute, 0-59 with leading space if < 10
     
-    ss         second, 00-61
-    s          second, 0-61
-    ?s         second, 0-61 with leading space if < 10
+    s          second, 0-59
+    ss         second, 00-59
+    ?s         second, 0-59 with leading space if < 10
     mmm        millisecond, 000-999
     uuuuuu     microsecond, 000000-999999
     
@@ -494,39 +591,50 @@ is used.  The format string may contain any of the following:
 
 Millisecond and microsecond require Time::HiRes, otherwise they'll
 always be zero.  Timezone requires POSIX, otherwise it'll be the empty
-string.
+string.  The second codes (C<s>, C<ss>, C<?s>) can be 60 or 61 in rare
+circumstances (leap seconds, if your system supports such).
 
 Anything in the format string other than the above patterns is left
-intact.  Also, any character preceded by a backslash is left alone and
-not used for any part of a format code.
+intact.  Any character preceded by a backslash is left alone and
+not used for any part of a format code.  See the L<QUOTING> section
+for more details.
 
 For the most part, each of the above formatting codes takes up as much
 space as the output string it generates.  The exceptions are the codes
 whose output is variable length: C<Weekday>, C<Month>, time zone, and
 the single-character codes.
 
+The mixed-case "Month", "Mon", "Weekday", and "Day" codes return the
+name of the month or weekday in the preferred case representation for
+the locale currently in effect.  Thus in an English-speaking locale,
+the seventh month would be "July" (uppercase first letter, lowercase
+rest); while in a French-speaking locale, it would be "juillet" (all
+lowercase).  See the L<QUOTING> section for ways to control the case
+of month/weekday names.
+
 Note that the "C<mm>", "C<m>", and "C<?m>" formats are ambiguous.
 C<%time> tries to guess whether you meant "month" or "minute" based on
 nearby characters in the format string.  Thus, a format of
 "C<yyyy/mm/dd hh:mm:ss>" is correctly parsed as "year month day, hour
-minute second".  To remove the ambiguity, you can use the following
-codes:
+minute second".  If C<%time> cannot determine whether you meant
+"month" or "minute", it leaves the C<mm>, C<m>, or C<?m> untranslated.
+To remove the ambiguity, you can use the following codes:
 
-    mm{on}       month, 01-12
     m{on}        month, 1-12
+    mm{on}       month, 01-12
     ?m{on}       month, 1-12 with leading space if < 10
     
-    mm{in}       minute, 00-59
     m{in}        minute, 0-59
+    mm{in}       minute, 00-59
     ?m{in}       minute, 0-59 with leading space if < 10
 
-In other words, append "C<{on}>" or "C<{in}>" to make "C<mm>", "C<m>",
+In other words, append "C<{on}>" or "C<{in}>" to make "C<m>", "C<mm>",
 or "C<?m>" unambiguous.
 
 Note: Previous version of Time::Format (before v0.05) used the codes
 "C<2mon>", "C<1mon>", "C<?mon>", "C<2min>", "C<1min>", and "C<?min>"
-denote unambiguous months and minutes.  These codes have been removed
-and are no longer supported.
+to denote unambiguous months and minutes.  These codes have been
+removed and are no longer supported.
 
 =item strftime
 
@@ -534,7 +642,7 @@ and are no longer supported.
  $strftime{$format, $unixtime}
  $strftime{$format}
 
-For those who prefer L<strftime(3)>'s weird % formats, or who need
+For those who prefer I<strftime(3)>'s weird % formats, or who need
 POSIX compliance, or who need week numbers or other features C<%time>
 does not provide.
 
@@ -597,6 +705,65 @@ C<$when> parameter in order to get the current time.
 
 =back
 
+=head1 QUOTING
+
+This section applies to the format strings used by C<%time> and
+C<time_format> only.
+
+Sometimes it is necessary to suppress expansion of some format
+characters in a format string.  For example:
+
+    $time{'Hour: hh; Minute: mm{in}; Second: ss'};
+
+In the above expression, the "H" in "Hour" would be expanded,
+as would the "d" in "Second".  The result would be something like:
+
+    8our: 08; Minute: 10; Secon17: 30
+
+It would not be a good solution to break the above statement out
+into three calls to %time:
+
+    "Hour: $time{hh}; Minute: $time{'mm{in}'}; Second: $time{ss}"
+
+because the time could change from one call to the next, which would
+be a problem when the numbers roll over (for example, a split second
+after 7:59:59).
+
+For this reason, you can escape individual format codes with a
+backslash:
+
+    $time{'\Hour: hh; Minute: mm{in}; Secon\d: ss'};
+
+Note that with double-quoted (and qq//) strings, the backslash must be
+doubled, because Perl first interpolates the string:
+
+    $time{"\\Hour: hh; Minute: mm{in}; Secon\\d: ss"};
+
+For added convenience, Time::Format simulates Perl's built-in \Q and
+\E inline quoting operators.  Anything in a string between a \Q and \E
+will not be interpolated as any part of any formatting code:
+
+    $time{'\QHour:\E hh; \QMinute:\E mm{in}; \QSecond:\E ss'};
+
+Again, within interpolated strings, the backslash must be doubled, or
+else Perl will interpret and remove the \Q...\E sequence before
+Time::Format gets it:
+
+    $time{"\\QHour:\\E hh; \\QMinute:\\E mm{in}; \\QSecond\\E: ss"};
+
+Time::Format also recognizes and simulates the \U, \L, \u, and \l
+sequences.  This is really only useful for finer control of the Month,
+Mon, Weekday, and Day formats.  For example, in some locales, the
+month names are all-lowercase by default.  At the start of a sentence,
+you may want to ensure that the first character is uppercase:
+
+    $time{'\uMonth \Qis the finest month of all.'};
+
+Again, be sure to use \Q, and be sure to double the backslashes in
+interpolated strings, otherwise you'll get something ugly like:
+
+    July i37 ste fine37t july of all.
+
 =head1 EXAMPLES
 
  $time{'Weekday Month d, yyyy'}   Thursday June 5, 2003
@@ -605,19 +772,27 @@ C<$when> parameter in order to get the current time.
  $time{yymmdd}                    030605
  $time{'yymmdd',time-86400}       030604
  $time{'dth of Month'}            5th of June
-
+ 
  $time{'H:mm:ss am'}              1:02:14 pm
  $time{'hh:mm:ss.uuuuuu'}         13:02:14.171447
-
+ 
  $time{'yyyy/mm{on}/dd hh:mm{in}:ss.mmm'}  2003/06/05 13:02:14.171
  $time{'yyyy/mm/dd hh:mm:ss.mmm'}          2003/06/05 13:02:14.171
-
+ 
  $time{"It's H:mm."}              It'14 1:02.    # OOPS!
  $time{"It'\\s H:mm."}            It's 1:02.     # Backslash fixes it.
 
+ # Rename a file based on today's date:
+ rename $file, "$file_$time{yyyymmdd}";
+ 
+ # Rename a file based on its last-modify date:
+ rename $file, "$file_$time{'yyyymmdd',(stat $file)[9]}";
+
+ # stftime examples
  $strftime{'%A %B %d, %Y'}                 Thursday June 05, 2003
  $strftime{'%A %B %d, %Y',time+86400}      Friday June 06, 2003
 
+ # manip examples
  $manip{'%m/%d/%Y'}                                   06/05/2003
  $manip{'%m/%d/%Y','yesterday'}                       06/04/2003
  $manip{'%m/%d/%Y','first monday in November 2000'}   11/06/2000
@@ -669,6 +844,14 @@ Example:
 
  use Time::Format ':all';
 
+=head1 BUGS
+
+The format string used by C<%time> must not have $; as a substring
+anywhere.  $; (by default, ASCII character 28, or 1C hex) is used to
+separate values passed to the tied hash, and thus Time::Format will
+interpret your format string to be two or more arguments if it
+contains $;.  The C<time_format> function does not have this problem.
+
 =head1 REQUIREMENTS
 
  I18N::Langinfo, if you want non-English locales to work.
@@ -687,18 +870,14 @@ Copyright (c) 2003 by Eric J. Roode. All Rights Reserved.  This module
 is free software; you can redistribute it and/or modify it under the
 same terms as Perl itself.
 
-If you have suggestions for improvement, please drop me a line.  If
-you make improvements to this software, I ask that you please send me
-a copy of your changes. Thanks.
-
 =begin gpg
 
 -----BEGIN PGP SIGNATURE-----
 Version: GnuPG v1.2.2 (GNU/Linux)
 
-iD8DBQE/DsIaY96i4h5M0egRAuETAKCe0IaFOAkJMW4XIzH8VY4KlXuWzQCfccDO
-DYhTJ//4jUbHQPELwjKRQQ8=
-=h+07
+iD8DBQE/GuPGY96i4h5M0egRAlVdAKC6qSNyzMcbL9m13VvtukT9lO2XWgCg+tNs
+nkaB23Rg2jZM86ELj7Avu1k=
+=XMkw
 -----END PGP SIGNATURE-----
 
 =end gpg
